@@ -19,7 +19,8 @@ if (base::getRversion() >= "2.15.1") {
 ## Needed to avoid notes when using data.table in functions:
 ## calculateAllele, calculateAT, calculateAT_gui, calculateAT6,
 ## calculateAT6_gui, plotBalance_gui, calculateLb, calculateRatio,
-## generateEPG, calculateSlope, calculateAllele, plotStutter_gui
+## generateEPG, calculateSlope, calculateAllele, plotStutter_gui,
+## calculateCopies, calculateHeight, plotContamination, calculateHb
 if (base::getRversion() >= "2.15.1") {
   utils::globalVariables(c("Height","Masked","Sample.File.Name","Dye",
                            "Hb","Marker","Lb", "H", "Amount", "Size",
@@ -27,5 +28,7 @@ if (base::getRversion() >= "2.15.1") {
                            "Group", "Allele", "Id", "Kit", "Lower", "Slope",
                            "Error", "Peaks", "Upper", "Total.Peaks",
                            "Allele.Proportion", "Sum.Peaks", "Allele.Frequency",
-                           "Ratio"))
+                           "Ratio", "Observed", "N.Alleles", "Copies",
+                           "Expected", "Proportion", "Samples", "Delta",
+                           "HMW", "LMW", "Small", "Large"))
 }
\ No newline at end of file
